summaryrefslogtreecommitdiffhomepage
path: root/Private/NewBoot/Source
diff options
context:
space:
mode:
Diffstat (limited to 'Private/NewBoot/Source')
-rw-r--r--Private/NewBoot/Source/CDROM/.NEWDEV2
-rw-r--r--Private/NewBoot/Source/CDROM/EFI/BOOT/.gitkeep0
-rw-r--r--Private/NewBoot/Source/HEL/AMD64/BootMain.cxx4
-rw-r--r--Private/NewBoot/Source/HEL/POWER/.gitkeep (renamed from Private/NewBoot/Source/CDROM/.gitkeep)0
-rw-r--r--Private/NewBoot/Source/HEL/POWER/BootCoreBoot.S (renamed from Private/NewBoot/Source/HEL/PowerPC/BootPowerPC.S)6
-rw-r--r--Private/NewBoot/Source/HEL/POWER/BootEPM.cxx (renamed from Private/NewBoot/Source/HEL/PowerPC/BootEPM.cxx)0
-rw-r--r--Private/NewBoot/Source/HEL/PowerPC/.gitkeep0
-rw-r--r--Private/NewBoot/Source/makefile4
8 files changed, 8 insertions, 8 deletions
diff --git a/Private/NewBoot/Source/CDROM/.NEWDEV b/Private/NewBoot/Source/CDROM/.NEWDEV
deleted file mode 100644
index d5d2badf..00000000
--- a/Private/NewBoot/Source/CDROM/.NEWDEV
+++ /dev/null
@@ -1,2 +0,0 @@
-[POWER_MANAGEMENT]
-ENFORCE_ACPI=YES \ No newline at end of file
diff --git a/Private/NewBoot/Source/CDROM/EFI/BOOT/.gitkeep b/Private/NewBoot/Source/CDROM/EFI/BOOT/.gitkeep
deleted file mode 100644
index e69de29b..00000000
--- a/Private/NewBoot/Source/CDROM/EFI/BOOT/.gitkeep
+++ /dev/null
diff --git a/Private/NewBoot/Source/HEL/AMD64/BootMain.cxx b/Private/NewBoot/Source/HEL/AMD64/BootMain.cxx
index e0d5d8c9..21b1505a 100644
--- a/Private/NewBoot/Source/HEL/AMD64/BootMain.cxx
+++ b/Private/NewBoot/Source/HEL/AMD64/BootMain.cxx
@@ -59,7 +59,7 @@ EFI_EXTERN_C EFI_API Int Main(EfiHandlePtr ImageHandle,
.Write(L"\r\n");
BootDeviceATA ataDev;
- Boolean isEpmFound = No;
+ Boolean isGptFound = No;
UInt32 MapKey = 0;
UInt32* SizePtr = nullptr;
@@ -121,7 +121,7 @@ EFI_EXTERN_C EFI_API Int Main(EfiHandlePtr ImageHandle,
ToolboxInitRsrc();
- ToolboxDrawZone(RGB(20, 20, 20), handoverHdrPtr->f_GOP.f_Height, handoverHdrPtr->f_GOP.f_Width, 0, 0);
+ ToolboxDrawZone(RGB(FF, FF, FF), handoverHdrPtr->f_GOP.f_Height, handoverHdrPtr->f_GOP.f_Width, 0, 0);
ToolboxClearRsrc();
diff --git a/Private/NewBoot/Source/CDROM/.gitkeep b/Private/NewBoot/Source/HEL/POWER/.gitkeep
index e69de29b..e69de29b 100644
--- a/Private/NewBoot/Source/CDROM/.gitkeep
+++ b/Private/NewBoot/Source/HEL/POWER/.gitkeep
diff --git a/Private/NewBoot/Source/HEL/PowerPC/BootEPM.cxx b/Private/NewBoot/Source/HEL/POWER/BootEPM.cxx
index 72276ef9..72276ef9 100644
--- a/Private/NewBoot/Source/HEL/PowerPC/BootEPM.cxx
+++ b/Private/NewBoot/Source/HEL/POWER/BootEPM.cxx
diff --git a/Private/NewBoot/Source/HEL/PowerPC/.gitkeep b/Private/NewBoot/Source/HEL/PowerPC/.gitkeep
deleted file mode 100644
index e69de29b..00000000
--- a/Private/NewBoot/Source/HEL/PowerPC/.gitkeep
+++ /dev/null
diff --git a/Private/NewBoot/Source/makefile b/Private/NewBoot/Source/makefile
index 25eb04c0..530abea8 100644
--- a/Private/NewBoot/Source/makefile
+++ b/Private/NewBoot/Source/makefile
@@ -38,6 +38,7 @@ invalid-recipe:
.PHONY: all
all: compile-amd64
+ mkdir -p CDROM/EFI/BOOT
$(LD_GNU) $(OBJ) $(LD_FLAGS) -o NewBoot.exe
$(COPY) NewBoot.exe CDROM/EFI/BOOT/BOOTX64.EFI
$(COPY) NewBoot.exe CDROM/EFI/BOOT/NEWBOOT.EFI
@@ -72,7 +73,8 @@ clean:
.PHONY: help
help:
@echo "=== HELP ==="
- @echo "epm-img: Format a disk using the Explicit Partition Map/GPT."
+ @echo "epm-img: Format a disk using the Explicit Partition Map."
+ @echo "gpt-img: Format a disk using the Explicit Partition Map."
@echo "clean: clean bootloader."
@echo "bootloader-amd64: Build bootloader. (PC AMD64)"
@echo "run-efi-amd64: Run bootloader. (PC AMD64)"
diff --git a/Private/NewBoot/Source/HEL/PowerPC/BootPowerPC.S b/Private/NewBoot/Source/HEL/POWER/BootCoreBoot.S
index 53d9d4f2..c611467d 100644
--- a/Private/NewBoot/Source/HEL/PowerPC/BootPowerPC.S
+++ b/Private/NewBoot/Source/HEL/POWER/BootCoreBoot.S
@@ -4,10 +4,10 @@
------------------------------------------- */
-.section .init
+.section .boot_hdr
.align 4
/* NewOS kernel header begin */
boot_hdr_mag:
.ascii "LX"
@@ -19,7 +19,7 @@ boot_hdr_ver:
boot_hdr_proc:
.long bootloader_start
/* NewOS kernel header end */
.extern bootloader_main
.extern bootloader_stack
@@ -4,10 +4,10 @@
.align 4
-/* NewOS kernel header begin */
+/* NewBoot boot header begin */
boot_hdr_mag:
.ascii "LX"
@@ -19,7 +19,7 @@ boot_hdr_ver:
boot_hdr_proc:
.long bootloader_start
-/* NewOS kernel header end */
+/* NewOS boot header end */
.extern bootloader_main
.extern bootloader_stack